@@ -29,6 +29,7 @@ autoapi_ignore = ["**/*version.py"]
 autodoc_typehints = "description"
 
 myst_enable_extensions = ["amsmath", "dollarmath"]
+myst_heading_anchors = 4
 
 # -- Options for HTML output -------------------------------------------------
 
@@ -46,9 +47,9 @@ html_theme_options = {
     "use_repository_button": True,
     "show_toc_level": 2,
 }
-html_context = {
-    "default_mode": "dark",
-}
+# html_context = {
+#     "default_mode": "dark",
+# }
 source_suffix = {
     ".rst": "restructuredtext",
     ".md": "myst-nb",
